PageSourceSearch

Results for app.rubic.no

about 47 candidate domains, page 1, 5286.2 ms; 45 candidates checked, 32 matched

tifviking.no rank 85636

https://www.tifviking.no/ html first_party collected 2026-09-24 10:03:02 UTC
preview

loaded by https://www.tifviking.no/

  • ow-button' data-duration='800' data-easing='easeInOutQuad'>Treningssenter</a><a href='https://app.rubic.no/Account/Signup?organizationID=17338#/form/profile' class='avia-slideshow-button avia-button byte 56875, line 325
  • on-wrap avia-button-center avia-builder-el-6 avia-builder-el-no-sibling ' ><a href='https://app.rubic.no/Account/Signup?organizationID=17338#/form/profile' class='avia-button avia-button-fullwidth byte 59229, line 330
https://www.tifviking.no/vaareidretter/ html first_party collected 2026-09-24 10:03:03 UTC
preview

loaded by https://www.tifviking.no/vaareidretter/

  • ton-wrap avia-button-right avia-builder-el-3 avia-builder-el-no-sibling ' ><a href="https://app.rubic.no/Account/Signup?organizationID=17338#/form/profile" class="avia-button avia-color-blue avia byte 42263, line 265
  • ton-wrap avia-button-left avia-builder-el-44 avia-builder-el-no-sibling ' ><a href='https://app.rubic.no/Account/Signup?organizationID=17338' class='avia-button avia-icon_select-yes-left-icon avi byte 70591, line 290

rubic.no rank 93136

https://www.rubic.no/ html first_party collected 2026-09-24 10:11:09 UTC
preview

loaded by https://www.rubic.no/

  • <h4>Logg inn</h4><ul><li><a href="https://id.rubic.no/">Rubic ID</a></li><li><a href="https://app.rubic.no/">Rubic Medlem</a></li><li><a href="https://activity.rubic.no/">Rubic Aktivitet</a></li><li>< byte 60516, line 84
https://www.rubic.no/arrangor/ html first_party collected 2026-09-24 10:11:11 UTC
preview

loaded by https://www.rubic.no/arrangor/

  • <h4>Logg inn</h4><ul><li><a href="https://id.rubic.no/">Rubic ID</a></li><li><a href="https://app.rubic.no/">Rubic Medlem</a></li><li><a href="https://activity.rubic.no/">Rubic Aktivitet</a></li><li>< byte 45004, line 9
https://www.rubic.no/medlem/ html first_party collected 2026-09-24 10:11:11 UTC
preview

loaded by https://www.rubic.no/medlem/

  • <h4>Logg inn</h4><ul><li><a href="https://id.rubic.no/">Rubic ID</a></li><li><a href="https://app.rubic.no/">Rubic Medlem</a></li><li><a href="https://activity.rubic.no/">Rubic Aktivitet</a></li><li>< byte 45630, line 9
https://www.rubic.no/regnskap/ html first_party collected 2026-09-24 10:11:13 UTC
preview

loaded by https://www.rubic.no/regnskap/

  • <h4>Logg inn</h4><ul><li><a href="https://id.rubic.no/">Rubic ID</a></li><li><a href="https://app.rubic.no/">Rubic Medlem</a></li><li><a href="https://activity.rubic.no/">Rubic Aktivitet</a></li><li>< byte 52874, line 50
https://www.rubic.no/sport/ html first_party collected 2026-09-24 10:11:09 UTC
preview

loaded by https://www.rubic.no/sport/

  • <h4>Logg inn</h4><ul><li><a href="https://id.rubic.no/">Rubic ID</a></li><li><a href="https://app.rubic.no/">Rubic Medlem</a></li><li><a href="https://activity.rubic.no/">Rubic Aktivitet</a></li><li>< byte 51859, line 9

hbrs.no rank 604420

https://www.hbrs.no/ html first_party collected 2026-09-24 20:54:42 UTC
preview

loaded by https://www.hbrs.no/

  • praksis i Oslo.<br><br>Har du lyst til Ã¥ være med?<br><br>👉 Meld deg pÃ¥ her:<br>https://app.rubic.no/Public/Events/49242<br><br>Kjenner du noen som kan ha glede av tilbudet? Del gjerne invitasjo byte 65846, line 432
  • ; Har du lyst til Ã¥ være med?&lt;br&gt; &lt;br&gt; 👉 Meld deg pÃ¥ her:&lt;br&gt; https://app.rubic.no/Public/Events/49242&lt;br&gt; &lt;br&gt; Kjenner du noen som kan ha glede av tilbudet? Del gj byte 69977, line 493

show all 28 matches (2 shown)

norbi.no rank 758305

https://norbi.no/ html first_party collected 2026-09-24 23:25:28 UTC
preview

loaded by https://norbi.no/

  • ass="menu-item menu-item-type-custom menu-item-object-custom menu-item-5553"><a href="https://app.rubic.no">Min side (Rubic)</a></li> </ul></div> <div class="mobile-menu-contact"> <p>Dampsag byte 46702, line 360
https://norbi.no/aktiviteter/ html first_party collected 2026-09-24 23:25:33 UTC
preview

loaded by https://norbi.no/aktiviteter/

  • ass="menu-item menu-item-type-custom menu-item-object-custom menu-item-5553"><a href="https://app.rubic.no">Min side (Rubic)</a></li> </ul></div> <div class="mobile-menu-contact"> <p>Dampsag byte 46595, line 361
https://norbi.no/bli-medlem/ html first_party collected 2026-09-24 23:25:30 UTC
preview

loaded by https://norbi.no/bli-medlem/

  • ass="menu-item menu-item-type-custom menu-item-object-custom menu-item-5553"><a href="https://app.rubic.no">Min side (Rubic)</a></li> </ul></div> <div class="mobile-menu-contact"> <p>Dampsag byte 46675, line 361
https://norbi.no/finn-fylkes-og-lokallag/ html first_party collected 2026-09-24 23:25:31 UTC
preview

loaded by https://norbi.no/finn-fylkes-og-lokallag/

  • ass="menu-item menu-item-type-custom menu-item-object-custom menu-item-5553"><a href="https://app.rubic.no">Min side (Rubic)</a></li> </ul></div> <div class="mobile-menu-contact"> <p>Dampsag byte 46260, line 358
https://norbi.no/kurs/ html first_party collected 2026-09-24 23:25:32 UTC
preview

loaded by https://norbi.no/kurs/

  • ass="menu-item menu-item-type-custom menu-item-object-custom menu-item-5553"><a href="https://app.rubic.no">Min side (Rubic)</a></li> </ul></div> <div class="mobile-menu-contact"> <p>Dampsag byte 47299, line 362

kns.no rank 1090775

https://www.kns.no/ html first_party collected 2026-09-25 03:50:28 UTC
preview

loaded by https://www.kns.no/

  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/Login?ReturnUrl=%2F"> <span class="elementor-icon-list-icon"> <sv byte 33920, line 439
https://www.kns.no/medlem/bli-medlem/ html first_party collected 2026-09-25 03:50:31 UTC
preview

loaded by https://www.kns.no/medlem/bli-medlem/

  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/Login?ReturnUrl=%2F"> <span class="elementor-icon-list-icon"> <sv byte 37923, line 442
  • ckground no-border-radius wp-element-button" style="background-color: #80714c;" href="https://app.rubic.no/Account/Signup?organizationID=9449#/form/profile"><mark class="has-inline-color has-white-col byte 55279, line 565
https://www.kns.no/miljo-og-klima/ html first_party collected 2026-09-25 03:50:36 UTC
preview

loaded by https://www.kns.no/miljo-og-klima/

  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/Login?ReturnUrl=%2F"> <span class="elementor-icon-list-icon"> <sv byte 33059, line 434
https://havn.kns.no/assets/index-DPK-Ptn9.js js first_party collected 2026-09-25 03:50:56 UTC
preview

loaded by https://havn.kns.no/vinterhavn

  • e:"text-sm text-muted-foreground",children:["Ikke medlem ennÃ¥?"," ",s.jsx("a",{href:"https://app.rubic.no/Account/Signup?organizationID=9449",target:"_blank",rel:"noopener noreferrer",className:"text byte 667515, line 624

nrof.no rank 1100694

https://www.nrof.no/ html first_party collected 2026-09-25 04:00:29 UTC
preview

loaded by https://www.nrof.no/

  • x"></div> </div> </div> <div class="headerminsvg"> <a href="https://app.rubic.no/" target="_blank"> <span class="header_icon_desk"> <!-- <svg class="headermin" byte 112361, line 472
https://www.nrof.no/om-nrof/ html first_party collected 2026-09-25 04:00:30 UTC
preview

loaded by https://www.nrof.no/om-nrof/

  • x"></div> </div> </div> <div class="headerminsvg"> <a href="https://app.rubic.no/" target="_blank"> <span class="header_icon_desk"> <img src="https://www.nrof.n byte 124326, line 485
https://www.nrof.no/om-nrof/kontakt-oss/ html first_party collected 2026-09-25 04:00:31 UTC
preview

loaded by https://www.nrof.no/om-nrof/kontakt-oss/

  • x"></div> </div> </div> <div class="headerminsvg"> <a href="https://app.rubic.no/" target="_blank"> <span class="header_icon_desk"> <img src="https://www.nrof.n byte 114379, line 475
https://www.nrof.no/om-nrof/rad-og-utvalg/ html first_party collected 2026-09-25 04:00:32 UTC
preview

loaded by https://www.nrof.no/om-nrof/rad-og-utvalg/

  • x"></div> </div> </div> <div class="headerminsvg"> <a href="https://app.rubic.no/" target="_blank"> <span class="header_icon_desk"> <img src="https://www.nrof.n byte 113470, line 471
https://www.nrof.no/om-nrof/soknad-om-medlemskap/ html first_party collected 2026-09-25 04:00:33 UTC
preview

loaded by https://www.nrof.no/om-nrof/soknad-om-medlemskap/

  • x"></div> </div> </div> <div class="headerminsvg"> <a href="https://app.rubic.no/" target="_blank"> <span class="header_icon_desk"> <img src="https://www.nrof.n byte 113504, line 471
  • r 25 til og med Ã¥ret du fyller 65 Ã¥r<br /> kr 350,- medlem fra og med det Ã¥ret du fyller 66 Ã¥r</p> <p><a href="https://app.rubic.no/Account/Signup?organizationID=22990">Søknadsskjema.</a></p> <p> byte 123871, line 588

hamkam.no rank 1109837

https://www.hamkam.no/nyheter/bli-hamkam-medlem html first_party collected 2026-09-25 04:09:49 UTC
preview

loaded by https://www.hamkam.no/nyheter/bli-hamkam-medlem

  • m Fotball 2026:</u></strong></p><p style="margin-left:0cm; margin-right:0cm"><a href="https://app.rubic.no/Account/Signup?organizationID=6634">Bli HamKam medlem HER</a><br><br>Bli med og ta del i kame byte 36391, line 541
  • e teller.</p><p>----</p><p>Et medlemskap i HamKam Fotball koster 500,-.&nbsp;<a href="https://app.rubic.no/Account/Signup?organizationID=6634">Registrer deg som HamKam-medlem NÃ…!</a></p><p>&nbsp;</p> byte 36611, line 541

lyn1896.no rank 1113928

https://www.lyn1896.no/ html first_party collected 2026-09-25 04:13:54 UTC
preview

loaded by https://www.lyn1896.no/

  • lynus-klubben"> LYNUS-klubben </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Register?organizationID=5030"> Bli klubbmedlem </a><a class="header__global_ byte 15537, line 185
  • lem-i-lynus-klubben"> LYNUS-klubben </a> <a class="item" href="https://app.rubic.no/Account/Register?organizationID=5030" target="_blank"> Bli klubbmedlem <span> byte 76585, line 1447
https://www.lyn1896.no/bilder-og-videoer/bli-frivillig html first_party collected 2026-09-25 04:13:56 UTC
preview

loaded by https://www.lyn1896.no/bilder-og-videoer/bli-frivillig

  • lynus-klubben"> LYNUS-klubben </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Register?organizationID=5030"> Bli klubbmedlem </a><a class="header__global_ byte 16326, line 190
  • lem-i-lynus-klubben"> LYNUS-klubben </a> <a class="item" href="https://app.rubic.no/Account/Register?organizationID=5030" target="_blank"> Bli klubbmedlem <span> byte 52474, line 864
https://www.lyn1896.no/partnere html first_party collected 2026-09-25 04:13:57 UTC
preview

loaded by https://www.lyn1896.no/partnere

  • lynus-klubben"> LYNUS-klubben </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Register?organizationID=5030"> Bli klubbmedlem </a><a class="header__global_ byte 14460, line 172
  • lem-i-lynus-klubben"> LYNUS-klubben </a> <a class="item" href="https://app.rubic.no/Account/Register?organizationID=5030" target="_blank"> Bli klubbmedlem <span> byte 67857, line 1087
https://www.lyn1896.no/partnerinnhold/bli-medlem-i-lynus-klubben html first_party collected 2026-09-25 04:13:58 UTC
preview

loaded by https://www.lyn1896.no/partnerinnhold/bli-medlem-i-lynus-klubben

  • lynus-klubben"> LYNUS-klubben </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Register?organizationID=5030"> Bli klubbmedlem </a><a class="header__global_ byte 16391, line 190
  • lem-i-lynus-klubben"> LYNUS-klubben </a> <a class="item" href="https://app.rubic.no/Account/Register?organizationID=5030" target="_blank"> Bli klubbmedlem <span> byte 55123, line 864

storhamarfotball.no rank 1118251

https://www.storhamarfotball.no/ html first_party collected 2026-09-25 04:17:58 UTC
preview

loaded by https://www.storhamarfotball.no/

  • <script type="text/javascript" src="https://app.rubic.no/scripts/embed.js"></script> byte 35886, line 372
  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/signup?organizationID=4361#/form/profile" target="_blank"> <span class="e byte 40626, line 434

show all 3 matches (2 shown)

https://www.storhamarfotball.no/fotballskoler/ html first_party collected 2026-09-25 04:18:02 UTC
preview

loaded by https://www.storhamarfotball.no/fotballskoler/

  • <script type="text/javascript" src="https://app.rubic.no/scripts/embed.js"></script> byte 36727, line 377
  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/signup?organizationID=4361#/form/profile" target="_blank"> <span class="e byte 41423, line 439

show all 3 matches (2 shown)

https://www.storhamarfotball.no/klubbhandbok/ html first_party collected 2026-09-25 04:17:59 UTC
preview

loaded by https://www.storhamarfotball.no/klubbhandbok/

  • <script type="text/javascript" src="https://app.rubic.no/scripts/embed.js"></script> byte 42866, line 384
  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/signup?organizationID=4361#/form/profile" target="_blank"> <span class="e byte 47607, line 446

show all 3 matches (2 shown)

https://www.storhamarfotball.no/klubbinfo/ html first_party collected 2026-09-25 04:18:00 UTC
preview

loaded by https://www.storhamarfotball.no/klubbinfo/

  • <script type="text/javascript" src="https://app.rubic.no/scripts/embed.js"></script> byte 36569, line 376
  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/signup?organizationID=4361#/form/profile" target="_blank"> <span class="e byte 41283, line 438

show all 3 matches (2 shown)

https://www.storhamarfotball.no/lag/ html first_party collected 2026-09-25 04:18:01 UTC
preview

loaded by https://www.storhamarfotball.no/lag/

  • <script type="text/javascript" src="https://app.rubic.no/scripts/embed.js"></script> byte 37029, line 376
  • <li class="elementor-icon-list-item elementor-inline-item"> <a href="https://app.rubic.no/Account/signup?organizationID=4361#/form/profile" target="_blank"> <span class="e byte 41737, line 438

show all 3 matches (2 shown)

haugerudif.no rank 1231821

https://www.haugerudif.no/om-oss html first_party collected 2026-09-25 06:03:03 UTC
preview

loaded by https://www.haugerudif.no/om-oss

  • i Haugerud innebærer og hvordan innmeldingsrutinene er.</strong></a></p> <p><a href="https://app.rubic.no/Account/Signup?organizationID=33975#/form/profile" target="_blank" rel="noopener noreferrer"> byte 8956, line 5
  • inene er.\u003c/strong\u003e\u003c/a\u003e\u003c/p\u003e\n\u003cp\u003e\u003ca href=\"https://app.rubic.no/Account/Signup?organizationID=33975#/form/profile\" target=\"_blank\" rel=\"noopener noreferr byte 26680, line 12

asker-skiklubb.no rank 1238647

https://www.asker-skiklubb.no/bli-medlem/ html first_party collected 2026-09-25 06:09:04 UTC
preview

loaded by https://www.asker-skiklubb.no/bli-medlem/

  • > <p class="wp-block-paragraph"><a rel="noreferrer noopener" target="_blank" href="https://app.rubic.no/Account/Signup?organizationID=29201#/form/profile">Meld deg inn her</a></p> <p class="wp-b byte 110527, line 767
  • d><td>kr 900,- </td></tr><tr><td><a rel="noreferrer noopener" target="_blank" href="https://app.rubic.no/Public/Events/30755">Livsvarig medlemskap</a></td><td>kr 7.500,-</td></tr></tbody></table></f byte 111398, line 783

holmenkollenskifestival.no rank 1245745

https://holmenkollenskifestival.no/ html first_party collected 2026-09-25 06:15:18 UTC
preview

loaded by https://holmenkollenskifestival.no/

  • }],"615":[{"rule":"contains","value":"ticketmaster.no\/"}],"614":[{"rule":"contains","value":"app.rubic.no\/"}]},"css_click":{"2833":["#gform_submit_button_3"],"2832":["#gform_submit_button_2"]}},"fac byte 22279, line 105
https://holmenkollenskifestival.no/bli-frivillig/ html first_party collected 2026-09-25 06:15:19 UTC
preview

loaded by https://holmenkollenskifestival.no/bli-frivillig/

  • }],"615":[{"rule":"contains","value":"ticketmaster.no\/"}],"614":[{"rule":"contains","value":"app.rubic.no\/"}]},"css_click":{"2833":["#gform_submit_button_3"],"2832":["#gform_submit_button_2"]}},"fac byte 24635, line 113
https://holmenkollenskifestival.no/de/ html first_party collected 2026-09-25 06:15:22 UTC
preview

loaded by https://holmenkollenskifestival.no/de/

  • }],"615":[{"rule":"contains","value":"ticketmaster.no\/"}],"614":[{"rule":"contains","value":"app.rubic.no\/"}]},"css_click":{"2833":["#gform_submit_button_3"],"2832":["#gform_submit_button_2"]}},"fac byte 22430, line 105
https://holmenkollenskifestival.no/en/ html first_party collected 2026-09-25 06:15:21 UTC
preview

loaded by https://holmenkollenskifestival.no/en/

  • }],"615":[{"rule":"contains","value":"ticketmaster.no\/"}],"614":[{"rule":"contains","value":"app.rubic.no\/"}]},"css_click":{"2833":["#gform_submit_button_3"],"2832":["#gform_submit_button_2"]}},"fac byte 22374, line 105
https://holmenkollenskifestival.no/sponsorer/ html first_party collected 2026-09-25 06:15:20 UTC
preview

loaded by https://holmenkollenskifestival.no/sponsorer/

  • }],"615":[{"rule":"contains","value":"ticketmaster.no\/"}],"614":[{"rule":"contains","value":"app.rubic.no\/"}]},"css_click":{"2833":["#gform_submit_button_3"],"2832":["#gform_submit_button_2"]}},"fac byte 22730, line 109

sandefjordfotball.no rank 1272671

https://www.sandefjordfotball.no/ html first_party collected 2026-09-25 06:38:04 UTC
preview

loaded by https://www.sandefjordfotball.no/

  • eader__global__nav" aria-label="Meny"> <a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=60420"> Bli medlem </a><a class="header__global__nav__ byte 14474, line 175
  • </a> </div> <div class="groupLink"> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=60420" target="_blank"> Bli medlem <span> <svg byte 82077, line 1459
https://www.sandefjordfotball.no/om-klubben/media-og-frikort html first_party collected 2026-09-25 06:38:08 UTC
preview

loaded by https://www.sandefjordfotball.no/om-klubben/media-og-frikort

  • eader__global__nav" aria-label="Meny"> <a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=60420"> Bli medlem </a><a class="header__global__nav__ byte 15861, line 180
  • </a> </div> <div class="groupLink"> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=60420" target="_blank"> Bli medlem <span> <svg byte 56916, line 862
https://www.sandefjordfotball.no/partnere html first_party collected 2026-09-25 06:38:07 UTC
preview

loaded by https://www.sandefjordfotball.no/partnere

  • eader__global__nav" aria-label="Meny"> <a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=60420"> Bli medlem </a><a class="header__global__nav__ byte 13947, line 162
  • </a> </div> <div class="groupLink"> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=60420" target="_blank"> Bli medlem <span> <svg byte 160665, line 2197
https://www.sandefjordfotball.no/partnere/partnerlogo/bli-partner html first_party collected 2026-09-25 06:38:07 UTC
preview

loaded by https://www.sandefjordfotball.no/partnere/partnerlogo/bli-partner

  • eader__global__nav" aria-label="Meny"> <a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=60420"> Bli medlem </a><a class="header__global__nav__ byte 16007, line 180
  • </a> </div> <div class="groupLink"> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=60420" target="_blank"> Bli medlem <span> <svg byte 61959, line 970

raufossfotball.no rank 1370378

https://www.raufossfotball.no/ html first_party collected 2026-09-25 08:03:58 UTC
preview

loaded by https://www.raufossfotball.no/

  • er"> Fotballskole/turneringer </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 15254, line 180
  • neringer"> Fotballskole/turneringer </a> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 79575, line 1354
https://www.raufossfotball.no/om-klubben/raufoss-il-toppfotball html first_party collected 2026-09-25 08:04:00 UTC
preview

loaded by https://www.raufossfotball.no/om-klubben/raufoss-il-toppfotball

  • er"> Fotballskole/turneringer </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 15990, line 180
  • neringer"> Fotballskole/turneringer </a> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 52815, line 943
https://www.raufossfotball.no/partnerforum html first_party collected 2026-09-25 08:04:01 UTC
preview

loaded by https://www.raufossfotball.no/partnerforum

  • er"> Fotballskole/turneringer </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 15508, line 180
  • neringer"> Fotballskole/turneringer </a> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 70555, line 1157
https://www.raufossfotball.no/raufoss-fotball-jravd html first_party collected 2026-09-25 08:04:02 UTC
preview

loaded by https://www.raufossfotball.no/raufoss-fotball-jravd

  • er"> Fotballskole/turneringer </a><a class="header__global__nav__item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 15736, line 180
  • neringer"> Fotballskole/turneringer </a> <a class="item" href="https://app.rubic.no/Account/Signup?organizationID=14489&amp;fbclid=IwAR263UxMptSWLhu6FNtFpLJKeFOw2yjjPz2ZgVt_Weeh byte 53620, line 879

mif.no rank 1462643

https://www.mif.no/bli-medlem/ html first_party collected 2026-09-25 09:29:07 UTC
preview

loaded by https://www.mif.no/bli-medlem/

  • pper"> <a class="elementor-button elementor-button-link elementor-size-md" href="https://app.rubic.no/Account/Signup?organizationID=18199" target="_blank" rel="nofollow"> <span class="eleme byte 47871, line 355
  • /b></h3><p>Innmelding i Mjøndalen IF gjøres via følgende link:</p><ul><li><a href="https://app.rubic.no/Account/Signup?organizationID=18199#/form/profile">https://app.rubic.no/Account/Signup?organi byte 50187, line 379

show all 3 matches (2 shown)

sotrask.no rank 1463423

https://sotrask.no/ html first_party collected 2026-09-25 09:29:42 UTC
preview

loaded by https://sotrask.no/

  • ounded-s *:duration-100" data-astro-cid-7w2b4rjc><li data-astro-cid-7w2b4rjc><a href="https://app.rubic.no/Account/Signup?organizationID=13808#/form/profile" target="_blank" data-astro-cid-7w2b4rjc>Bl byte 18672, line 12
https://sotrask.no/basketball/ html first_party collected 2026-09-25 09:29:46 UTC
preview

loaded by https://sotrask.no/basketball/

  • ounded-s *:duration-100" data-astro-cid-7w2b4rjc><li data-astro-cid-7w2b4rjc><a href="https://app.rubic.no/Account/Signup?organizationID=13808#/form/profile" target="_blank" data-astro-cid-7w2b4rjc>Bl byte 18659, line 11
https://sotrask.no/fotball/ html first_party collected 2026-09-25 09:29:43 UTC
preview

loaded by https://sotrask.no/fotball/

  • ounded-s *:duration-100" data-astro-cid-7w2b4rjc><li data-astro-cid-7w2b4rjc><a href="https://app.rubic.no/Account/Signup?organizationID=13808#/form/profile" target="_blank" data-astro-cid-7w2b4rjc>Bl byte 18647, line 11
https://sotrask.no/handball/ html first_party collected 2026-09-25 09:29:44 UTC
preview

loaded by https://sotrask.no/handball/

  • ounded-s *:duration-100" data-astro-cid-7w2b4rjc><li data-astro-cid-7w2b4rjc><a href="https://app.rubic.no/Account/Signup?organizationID=13808#/form/profile" target="_blank" data-astro-cid-7w2b4rjc>Bl byte 18651, line 11
https://sotrask.no/turn-dans/ html first_party collected 2026-09-25 09:29:45 UTC
preview

loaded by https://sotrask.no/turn-dans/

  • ounded-s *:duration-100" data-astro-cid-7w2b4rjc><li data-astro-cid-7w2b4rjc><a href="https://app.rubic.no/Account/Signup?organizationID=13808#/form/profile" target="_blank" data-astro-cid-7w2b4rjc>Bl byte 18655, line 11

folketsparti.no rank 1527081

https://www.folketsparti.no/ html first_party collected 2026-09-25 10:28:35 UTC
preview

loaded by https://www.folketsparti.no/

  • yle-local-2166-h24-outer d-inline-flex h-element"><a h-use-smooth-scroll="true" href="https://app.rubic.no/Account/Signup?organizationID=17710" target="_blank" data-colibri-id="2166-h24" class="d-flex byte 162640, line 2058
https://www.folketsparti.no/artikler/ html first_party collected 2026-09-25 10:28:37 UTC
preview

loaded by https://www.folketsparti.no/artikler/

  • yle-local-2166-h24-outer d-inline-flex h-element"><a h-use-smooth-scroll="true" href="https://app.rubic.no/Account/Signup?organizationID=17710" target="_blank" data-colibri-id="2166-h24" class="d-flex byte 158990, line 1759
https://www.folketsparti.no/partiprogram-2019-2023/ html first_party collected 2026-09-25 10:28:42 UTC
preview

loaded by https://www.folketsparti.no/partiprogram-2019-2023/

  • yle-local-2166-h24-outer d-inline-flex h-element"><a h-use-smooth-scroll="true" href="https://app.rubic.no/Account/Signup?organizationID=17710" target="_blank" data-colibri-id="2166-h24" class="d-flex byte 150311, line 1688
https://www.folketsparti.no/partiprogram2021/ html first_party collected 2026-09-25 10:28:39 UTC
preview

loaded by https://www.folketsparti.no/partiprogram2021/

  • yle-local-7931-h24-outer d-inline-flex h-element"><a h-use-smooth-scroll="true" href="https://app.rubic.no/Account/Signup?organizationID=17710" target="_blank" data-colibri-id="7931-h24" class="d-flex byte 203055, line 1807
https://www.folketsparti.no/prinsipprogram/ html first_party collected 2026-09-25 10:28:41 UTC
preview

loaded by https://www.folketsparti.no/prinsipprogram/

  • yle-local-2166-h24-outer d-inline-flex h-element"><a h-use-smooth-scroll="true" href="https://app.rubic.no/Account/Signup?organizationID=17710" target="_blank" data-colibri-id="2166-h24" class="d-flex byte 151461, line 1551

vil.no rank 1531274

https://www.vil.no/ html first_party collected 2026-09-25 10:31:55 UTC
preview

loaded by https://www.vil.no/

  • tem-6071617" class="menu-item menu-item-type-custom menu-item-object-custom"><a href="https://app.rubic.no/Account/Signup?organizationID=24043#/form/profile">Bli medlem</a></li><li id="menu-item-61273 byte 517044, line 12683
  • fl-node-content"> <div class="pp-infobox-wrap"> <a class="pp-infobox-link" href="https://app.rubic.no/Account/Signup?organizationID=24043#/form/profile" target="_self"> <div class="pp-infobox la byte 537026, line 12987

show all 3 matches (2 shown)

https://www.vil.no/fotball/ html first_party collected 2026-09-25 10:31:57 UTC
preview

loaded by https://www.vil.no/fotball/

  • tem-6071617" class="menu-item menu-item-type-custom menu-item-object-custom"><a href="https://app.rubic.no/Account/Signup?organizationID=24043#/form/profile">Bli medlem</a></li><li id="menu-item-61273 byte 361234, line 7281
https://www.vil.no/handball/ html first_party collected 2026-09-25 10:31:57 UTC
preview

loaded by https://www.vil.no/handball/

  • tem-6071617" class="menu-item menu-item-type-custom menu-item-object-custom"><a href="https://app.rubic.no/Account/Signup?organizationID=24043#/form/profile">Bli medlem</a></li><li id="menu-item-61273 byte 371006, line 7289
https://www.vil.no/klatring/ html first_party collected 2026-09-25 10:32:00 UTC
preview

loaded by https://www.vil.no/klatring/

  • tem-6071617" class="menu-item menu-item-type-custom menu-item-object-custom"><a href="https://app.rubic.no/Account/Signup?organizationID=24043#/form/profile">Bli medlem</a></li><li id="menu-item-61273 byte 360486, line 7276
https://www.vil.no/turn/ html first_party collected 2026-09-25 10:32:00 UTC
preview

loaded by https://www.vil.no/turn/

  • tem-6071617" class="menu-item menu-item-type-custom menu-item-object-custom"><a href="https://app.rubic.no/Account/Signup?organizationID=24043#/form/profile">Bli medlem</a></li><li id="menu-item-61273 byte 360169, line 7276

bastionen.no rank 1550892

https://www.bastionen.no/ html first_party collected 2026-09-25 10:47:48 UTC
preview

loaded by https://www.bastionen.no/

  • &quot;href&quot;: &quot;https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile&quot;, byte 63776, line 253
  • der theme-btn--primary-inverse sqs-button-element--primary" href="https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile" target="_blank" byte 131589, line 769

show all 6 matches (2 shown)

https://www.bastionen.no/about html first_party collected 2026-09-25 10:47:50 UTC
preview

loaded by https://www.bastionen.no/about

  • &quot;href&quot;: &quot;https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile&quot;, byte 60418, line 246
  • der theme-btn--primary-inverse sqs-button-element--primary" href="https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile" target="_blank" byte 173863, line 762

show all 5 matches (2 shown)

https://www.bastionen.no/cart html first_party collected 2026-09-25 10:47:49 UTC
preview

loaded by https://www.bastionen.no/cart

  • uot;layout&quot;: &quot;navRight&quot;, &quot;action&quot;: { &quot;href&quot;: &quot;https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile&quot;, &quot;buttonText&quot;: &quot;BLI MED byte 58949, line 246
  • der theme-btn--primary-inverse sqs-button-element--primary" href="https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile" target="_blank" byte 71295, line 760

show all 5 matches (2 shown)

https://www.bastionen.no/medlem html first_party collected 2026-09-25 10:47:52 UTC
preview

loaded by https://www.bastionen.no/medlem

  • &quot;href&quot;: &quot;https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile&quot;, byte 59175, line 246
  • der theme-btn--primary-inverse sqs-button-element--primary" href="https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile" target="_blank" byte 85644, line 762

show all 6 matches (2 shown)

https://www.bastionen.no/nyheter html first_party collected 2026-09-25 10:47:51 UTC
preview

loaded by https://www.bastionen.no/nyheter

  • &quot;href&quot;: &quot;https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile&quot;, byte 60046, line 247
  • der theme-btn--primary-inverse sqs-button-element--primary" href="https://app.rubic.no/Account/Signup?organizationID=5731#/form/profile" target="_blank" byte 101107, line 763

show all 5 matches (2 shown)